interface StackFrame {
    args?: any[];
    columnNumber?: number;
    lineNumber?: number;
    fileName?: string;
    functionName?: string;
    source?: string;
}
/**
 * Simplified representation of a stack frame.
 */
interface StackFrameLite {
    function?: string;
    args?: any[];
    file?: string;
    col?: number;
    line?: number;
    raw?: string;
}
interface ParseOptions {
    /**
     * Slice the stack from the given index.
     * This could save some computation to avoid parsing unneeded stack frames.
     */
    slice?: number | [number, number];
}

/**
 * Port from https://github.com/stacktracejs/error-stack-parser
 */

/**
 * Given an Error object, extract the most information from it.
 *
 * @param {Error} error object
 * @return {Array} of StackFrames
 */
declare function parse(error: Error, options?: ParseOptions): StackFrameLite[];
declare function extractLocation(urlLike: string): string[] | readonly [string, string | undefined, string | undefined];
declare function parseV8OrIE(error: Error, options?: ParseOptions): StackFrameLite[];
declare function parseFFOrSafari(error: Error, options?: ParseOptions): StackFrameLite[];
declare function parseOpera(e: Error, options?: ParseOptions): StackFrameLite[];
declare function parseOpera9(e: Error, options?: ParseOptions): StackFrameLite[];
declare function parseOpera10(e: Error, options?: ParseOptions): StackFrameLite[];
declare function parseOpera11(error: Error, options?: ParseOptions): StackFrameLite[];

export { type ParseOptions, type StackFrame, type StackFrameLite, extractLocation, parse, parseFFOrSafari, parseOpera, parseOpera10, parseOpera11, parseOpera9, parseV8OrIE };
